==> camunda-engine-7.10.0-sources.jar: org/camunda/bpm/engine/impl/cmd/SaveTenantCmd.java <==
/*
 * Copyright © 2012 - 2018 camunda services GmbH and various authors (info@camunda.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmd;

import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureNotNull;
import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureWhitelistedResourceId;

import java.io.Serializable;

import org.camunda.bpm.engine.identity.Tenant;
import org.camunda.bpm.engine.impl.interceptor.Command;
import org.camunda.bpm.engine.impl.interceptor.CommandContext;

public class SaveTenantCmd extends AbstractWritableIdentityServiceCmd<Void> implements Command<Void>, Serializable {

  private static final long serialVersionUID = 1L;
  protected Tenant tenant;

  public SaveTenantCmd(Tenant tenant) {
    this.tenant = tenant;
  }

  @Override
  protected Void executeCmd(CommandContext commandContext) {
    ensureNotNull("tenant", tenant);
    ensureWhitelistedResourceId(commandContext, "Tenant", tenant.getId());

    commandContext
      .getWritableIdentityProvider()
      .saveTenant(tenant);

    return null;
  }

}

==> camunda-engine-7.16.0-sources.jar: org/camunda/bpm/engine/impl/cmd/SaveTenantCmd.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmd;

import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureNotNull;
import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureWhitelistedResourceId;

import java.io.Serializable;

import org.camunda.bpm.engine.identity.Tenant;
import org.camunda.bpm.engine.impl.identity.IdentityOperationResult;
import org.camunda.bpm.engine.impl.interceptor.Command;
import org.camunda.bpm.engine.impl.interceptor.CommandContext;

public class SaveTenantCmd extends AbstractWritableIdentityServiceCmd<Void> implements Command<Void>, Serializable {

  private static final long serialVersionUID = 1L;
  protected Tenant tenant;

  public SaveTenantCmd(Tenant tenant) {
    this.tenant = tenant;
  }

  @Override
  protected Void executeCmd(CommandContext commandContext) {
    ensureNotNull("tenant", tenant);
    ensureWhitelistedResourceId(commandContext, "Tenant", tenant.getId());

    IdentityOperationResult operationResult = commandContext
      .getWritableIdentityProvider()
      .saveTenant(tenant);

    commandContext.getOperationLogManager().logTenantOperation(operationResult, tenant.getId());

    return null;
  }

}
